summaryrefslogtreecommitdiffstats
path: root/kmymoney2/views/kinstitutionsview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/views/kinstitutionsview.h')
-rw-r--r--kmymoney2/views/kinstitutionsview.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kmymoney2/views/kinstitutionsview.h b/kmymoney2/views/kinstitutionsview.h
index 9c1ab96..6293f35 100644
--- a/kmymoney2/views/kinstitutionsview.h
+++ b/kmymoney2/views/kinstitutionsview.h
@@ -46,7 +46,7 @@ class KInstitutionsView : public KInstitutionsViewDecl
private:
public:
- KInstitutionsView(TQWidget *tqparent=0, const char *name=0);
+ KInstitutionsView(TQWidget *parent=0, const char *name=0);
virtual ~KInstitutionsView();
public slots:
@@ -71,10 +71,10 @@ protected:
void loadAccounts(void);
// load accounts that are kept at a specific institution
- void loadSubAccounts(KMyMoneyAccountTreeItem* tqparent, const TQString& institutionId);
+ void loadSubAccounts(KMyMoneyAccountTreeItem* parent, const TQString& institutionId);
- // load stock accounts under the investment account (tqparent)
- void loadSubAccounts(KMyMoneyAccountTreeItem* tqparent);
+ // load stock accounts under the investment account (parent)
+ void loadSubAccounts(KMyMoneyAccountTreeItem* parent);
protected slots:
void slotUpdateNetWorth(void);